@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: gtk
-version: 0.12.0
-id: gtk-0.12.0-7dcdd93cfdbc36dc65e2bd7fe32e4978
+version: 0.12.3.1
+id: gtk-0.12.3.1-28c6e9e8b6ee0308cb54914f61306856
 
 license: LGPL-2.1
 copyright: (c) 2001-2010 The Gtk2Hs Team
-maintainer: gtk2hs-users@sourceforge.net
+maintainer: gtk2hs-users@lists.sourceforge.net
 stability: provisional
-homepage: http://www.haskell.org/gtk2hs/
+homepage: http://projects.haskell.org/gtk2hs/
 package-url:
+synopsis: Binding to the Gtk+ graphical user interface library.
 description: This is the core library of the Gtk2Hs suite of libraries for Haskell
              based on Gtk+. Gtk+ is an extensive and mature multi-platform toolkit
              for creating graphical user interfaces.
@@ -171,40 +172,39 @@ hidden-modules: Graphics.UI.Gtk.Gdk.Enums
                 Graphics.UI.Gtk.Abstract.ContainerChildProperties
                 Graphics.UI.Gtk.General.DNDTypes Graphics.UI.Gtk.General.Threading
                 Graphics.UI.Gtk.Types Graphics.UI.Gtk.Signals
-import-dirs: /usr/local/lib/ghc/gtk-0.12.0
-library-dirs: /usr/local/lib/ghc/gtk-0.12.0 /usr/local/lib
+trusted: False
+import-dirs: /usr/local/lib/ghc/gtk-0.12.3.1
+library-dirs: /usr/local/lib/ghc/gtk-0.12.3.1 /usr/local/lib
               /usr/X11R6/lib
-hs-libraries: HSgtk-0.12.0
+hs-libraries: HSgtk-0.12.3.1
 extra-libraries: gthread-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
-                 Xext Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes atk-1.0
-                 cairo pixman-1 pthread-stubs GL png xcb-shm xcb-render xcb Xrender
-                 X11 gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m gobject-2.0
-                 glib-2.0 intl iconv fontconfig expat freetype z
+                 Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes X11
+                 Xext atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m
+                 gobject-2.0 glib-2.0 intl iconv fontconfig expat freetype z
 extra-ghci-libraries:
 include-dirs: /usr/local/include/gtk-2.0
               /usr/local/lib/gtk-2.0/include /usr/local/include/pango-1.0
               /usr/local/include/gio-unix-2.0/ /usr/X11R6/include
               /usr/local/include/cairo /usr/local/include/atk-1.0
-              /usr/X11R6/include/pixman-1 /usr/include/dev/pci/drm
-              /usr/local/include/gdk-pixbuf-2.0 /usr/local/include/libpng
+              /usr/X11R6/include/pixman-1 /usr/local/include/gdk-pixbuf-2.0
+              /usr/local/include/libpng /usr/local/include/harfbuzz
               /usr/local/include/glib-2.0 /usr/local/lib/glib-2.0/include
               /usr/local/include /usr/X11R6/include/freetype2
 includes:
-depends: array-0.3.0.2-143060371bda4ff52c270d1067551fe8
-         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         cairo-0.12.0-0f0db7bd16540db34af2e7f3a09ec4bc
-         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
-         gio-0.12.0-99d30ef09e181ca08d871b72e0923b31
-         glib-0.12.0-6c035e26ff59497b45e0ba131f8e7109
-         haskell98-1.1.0.1-77a2638462dcb3e7c4b25de628e54ca6
-         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
-         pango-0.12.0-6defb18f3b0a95dc8750a2e7e2b75f47
+depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
+         base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
+         cairo-0.12.3.1-cf457dfe25292e09fa980e3d9b270c9e
+         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
+         gio-0.12.3-f342b5f4ffd40d3a7b464b22b3f89f5f
+         glib-0.12.3.1-802d98cfe9a88c3ac80f8e30d4b86d4a
+         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
+         pango-0.12.3-c793132a2b917d90a03e1195fab8c726
 hugs-options:
 cc-options:
-ld-options: -pthread
+ld-options: -pthread "-Wl,-rpath-link,/usr/X11R6/lib"
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-gtk-0.12.0/html/gtk.haddock
-haddock-html: /usr/local/share/doc/hs-gtk-0.12.0/html
+haddock-interfaces: /usr/local/share/doc/hs-gtk-0.12.3.1/html/gtk.haddock
+haddock-html: /usr/local/share/doc/hs-gtk-0.12.3.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
